@@ -31,7 +31,7 @@ public:
     MainWindow* newWindow();
 
 private:
-    void loadSettings();
+    int loadSettings();
 
 public:
     QList<Bookmark> m_bookmarks;
