@@ -87,27 +87,6 @@ void BookmarksDlg::on_listWidget_itemClicked(QListWidgetItem* pItem)
 
     m_pItem = pItem;
     m_bookmark = var.value<Bookmark>();
-}
-
-void BookmarksDlg::on_listWidget_itemDoubleClicked(QListWidgetItem* pItem)
-{
-    if ( m_bookmark.isNull() ) return;
-    accept();
-}
-
-void BookmarksDlg::on_listWidget_customContextMenuRequested(QPoint pos)
-{
-    /*
-    QModelIndex t = m_pUI->listWidget->indexAt(pos);
-    QListWidgetItem* pItem = m_pUI->listWidget->item(t.row());
-    pItem->setSelected(true); // even a right click will select the item
-
-    QVariant var;
-    var = pItem->data(Qt::UserRole);
-    if ( !var.isValid() ) return;
-
-    m_bookmark = var.value<Bookmark>();
-    */
 
     if ( !m_pItem || m_bookmark.isNull() ) return;
 
@@ -127,6 +106,33 @@ void BookmarksDlg::on_listWidget_customContextMenuRequested(QPoint pos)
     m_pItem->setText(m_bookmark.title());
 }
 
+/*
+void BookmarksDlg::on_listWidget_itemDoubleClicked(QListWidgetItem* pItem)
+{
+    if ( m_bookmark.isNull() ) return;
+    accept();
+}
+
+void BookmarksDlg::on_listWidget_customContextMenuRequested(QPoint pos) {
+    if ( !m_pItem || m_bookmark.isNull() ) return;
+
+    BookmarkDlg dlg(this);
+    dlg.setTitle(m_bookmark.title());
+    dlg.setUrl(m_bookmark.url());
+    connect((QObject*)dlg.removeBtt(), SIGNAL(clicked()), this, SLOT(onRemoveBookmark()));
+    if ( dlg.exec() != QDialog::Accepted ) return;
+
+    int index = m_bookmarks.indexOf(m_bookmark);
+
+    // update
+    m_bookmark.setTitle(dlg.title());
+    m_bookmark.setUrl(dlg.url());
+    m_bookmarks.replace(index, m_bookmark);
+
+    m_pItem->setText(m_bookmark.title());
+}
+*/
+
 void BookmarksDlg::onRemoveBookmark() {
     m_bookmarks.removeAll(m_bookmark);
 
