@@ -160,7 +160,8 @@ void MainWindow::createMenu() {
 #endif
 
     pMenu = menuBar()->addMenu("&Bookmarks");
-    pMenu->addAction("Bookmarks", this, SLOT(on_actionBookmarks_triggered()));
+    pMenu->addAction("Bookmarks", this, SLOT(bookmarks()));
+    pMenu->addAction("Edit Bookmarks", this, SLOT(on_actionBookmarks_triggered()));
     pMenu->addAction("Add Bookmark", this, SLOT(on_actionAdd_Bookmark_triggered()));
 
 #ifdef Q_WS_MAEMO_5
@@ -377,6 +378,10 @@ void MainWindow::closeEvent(QCloseEvent *pEvent)
 
     // top most
     m_webPage.saveCookies();
+    bookmarks();
+}
+
+void MainWindow::bookmarks() {
     if ( !m_pWebView ) return;
 
     QString url = m_pWebView ? m_pWebView->url().toString() : QString::null;
@@ -385,7 +390,7 @@ void MainWindow::closeEvent(QCloseEvent *pEvent)
         "<style type=\"text/css\">TD.link {text-align:center; height: 50px; background-color: #ffccaa; border: 2px solid black; }</style>"
         "<BODY style='font-size:14pt; font-family: Verdana;text-aling:center;'>"
         "<table style='width:100%;'>"
-        "<tr><td><b>Quick Links</b></td></tr>";
+        "<tr><td><b>Quick Links</b></td></tr>"
         "<tr><td class='link' onclick='document.location.href=\"" + url + "\"'>" + m_pWebView->title() + "</td></tr>"
         "<tr><td class='link' onclick='document.location.href=\"http://www.crochik.com/macuco\"'>Macuco Home</td></tr>"
         "<tr><td class='link' onclick='document.location.href=\"http://www.crochik.com/macuco2/latest.html\"'>About/FAQ/Donate</td></tr>";
@@ -399,7 +404,6 @@ void MainWindow::closeEvent(QCloseEvent *pEvent)
 
     html += "</table></BODY></HTML>";
     m_webPage.mainFrame()->setHtml(html);
-
 }
 
 void MainWindow::zoomIn() {
@@ -440,7 +444,7 @@ void MainWindow::keyPressEvent(QKeyEvent *event)
 
         case Qt::Key_B:
             if ( (event->modifiers()&Qt::ControlModifier) != Qt::ControlModifier  ) break;
-            on_actionBookmarks_triggered();
+            bookmarks();
             break;
 
         case Qt::Key_G:
