@@ -1,6 +1,8 @@
 #include "webviewwindow.h"
 #include "qwebviewselectionsuppressor.h"
 
+#include "waitingbutton.h"
+
 WebViewWindow::WebViewWindow(MainWindow *pParent) :
     MainWindow(pParent)
 {
@@ -23,6 +25,9 @@ WebViewWindow::WebViewWindow(MainWindow *pParent) :
     m_pWebView->setPage(&m_webPage);
     setCentralWidget(m_pWebView);
 
+    // cancel
+    if (m_pWaitingButton) connect(m_pWaitingButton, SIGNAL(clicked()), m_pWebView, SLOT(stop()));
+
     startUp();
 }
 
@@ -39,21 +44,14 @@ void WebViewWindow::onScroll(const QPoint &offset) {
 }
 
 void WebViewWindow::updateTitle() {
-#ifndef Q_WS_MAEMO_5
     QString title = m_currentUrl.isEmpty() || !m_pWebView ? "Macuco" : m_pWebView->title();
+
+#ifndef Q_WS_MAEMO_5
     if ( m_webPage.isIphoneUserAgent() ) title += " - iPhone";
     title += QString(" - %1%").arg(QString::number(m_zoomFactor*100, 'f', 0));
-
-    setWindowTitle(title);
 #endif
 
-}
-
-MainWindow* WebViewWindow::createWindow() {
-    if ( m_pParent ) return m_pParent->createWindow();
-
-    // top most
-    return new WebViewWindow(this);
+    setWindowTitle(title);
 }
 
 void WebViewWindow::visitUrl(QUrl url) {
